package compbio.controllers;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import java.util.Map;

import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import compbio.cassandra.DateBean;
import compbio.cassandra.TotalJobsStatisticBean;
import compbio.statistic.CassandraRequester;

/**
 * @author Alexander Sherstnev
 * @author Natasha Sherstneva
 */
@Controller
public class DailyStatisticsController {

	@RequestMapping(value = "/stat", method = RequestMethod.GET)
	public String initFindForm(Map<String, Object> model) {
		Calendar cal = Calendar.getInstance();
		String date2 = cal.get(Calendar.YEAR) + "/" + (cal.get(Calendar.MONTH) + 1) + "/" + cal.get(Calendar.DATE);
		cal.add(Calendar.DATE, -3);
		String date1 = cal.get(Calendar.YEAR) + "/" + (cal.get(Calendar.MONTH) + 1) + "/" + cal.get(Calendar.DATE);

		model.put("date1", date1);
		model.put("date2", date2);

		return "queryJobStatistics";
	}

	@RequestMapping(value = "/stat/query", method = RequestMethod.GET)
	public String findJobsInPeriod(@RequestParam("date1") String date1, @RequestParam("date2") String date2,
			@RequestParam("option") String option, Map<String, Object> model) {
		final long startTime = System.currentTimeMillis();

		CassandraRequester cr = new CassandraRequester();
		if (option.equals("AllDates,off")) {
			Calendar cal = Calendar.getInstance();
			date1 = cr.earliestDateString();
			date2 = cal.get(Calendar.YEAR) + "/" + (cal.get(Calendar.MONTH) + 1) + "/" + cal.get(Calendar.DAY_OF_MONTH);
		}
		model.put("date1", date1);
		model.put("date2", date2);
		TotalJobsStatisticBean res = cr.countJobs(date1, date2);
		model.put("result", res);
		model.put("ndays", res.getDateTotal().size());
		final long endTime = System.currentTimeMillis();
		model.put("timeExecution", (endTime - startTime));
		model.put("option", option);
		return "/reportJobStatistics";
	}

	@RequestMapping(value = "/stat/oneday", method = RequestMethod.GET)
	public String findJobsInOneDay(@RequestParam("date") String date, Map<String, Object> model) throws ParseException {
		final long startTime = System.currentTimeMillis();

		String realdate;
		final SimpleDateFormat formaterDDMMYY = new SimpleDateFormat("dd/MM/yyyy");
		final SimpleDateFormat formaterYYMMDD = new SimpleDateFormat("yyyy/MM/dd");
		try {
			long thetime = formaterYYMMDD.parse(date).getTime();
			if (thetime < 0) {
				realdate = date;
			} else {
				realdate = formaterDDMMYY.format(new Date(thetime));
			}
		} catch (ParseException e) {
			realdate = date;
		}

		CassandraRequester cr = new CassandraRequester();
		// IMPORTANT: input should be suppied in the format: DD/MM/YYYY
		DateBean r = cr.readJobByDay(realdate);
		model.put("results", r);
		if (r != null)
			model.put("njobs", r.getJobidAndSeq().size());
		model.put("date", realdate);
		final long endTime = System.currentTimeMillis();
		model.put("timeExecution", (endTime - startTime));
		return "/reportJobStatisticsOneDay";
	}
}
